@@ -10,12 +10,9 @@ class OpenViduSubscriber(object):
     session_id: str
     stream_id: str
     created_at: datetime
-    publisher: str
 
     def __init__(self, session: BaseUrlSession, session_id: str, data: dict):
         self._session = session
         self.session_id = session_id
         self.stream_id = data['streamId']
         self.created_at = datetime.utcfromtimestamp(data['createdAt'] / 1000.0)
-        self.publisher = data['publisher']
-
